@@ -3,15 +3,17 @@
 This is expected to fail validation:
 
     $ flake8 --select RST RST203/def_list.py
-    RST203/def_list.py:21:1: RST203 Definition list ends without a blank line; unexpected unindent.
+    RST203/def_list.py:23:1: RST203 Definition list ends without a blank line; unexpected unindent.
 
 In this case, the four parameters should all have their own ``:parameter``
 opening.
 """  # noqa: E501
 
 
-def box(x1, y1, width=500, height=100):
-    """Draw a box.
+def box(*args, **kwargs):
+    """box(x1, y1, width, height) -> Graphics
+
+    Draw a box.
 
     :parameter
         x1: - required left coordinate, float
@@ -19,5 +21,5 @@ def box(x1, y1, width=500, height=100):
         width: - optional width, float
         height: - optional height, float
     :return: Graphics object
-    """
+    """  # noqa: D400, D402
     pass
